#[repr(C)]pub struct TopologyLeaseResponse {}Trait Implementations
Sourceimpl Clone for TopologyLeaseResponse
impl Clone for TopologyLeaseResponse
Sourcefn clone(&self) -> TopologyLeaseResponse
fn clone(&self) -> TopologyLeaseResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TopologyLeaseResponse
impl Debug for TopologyLeaseResponse
Sourceimpl<'a, ___E> Encode<TopologyLeaseResponse, ___E> for &'a TopologyLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TopologyLeaseResponse, ___E> for &'a TopologyLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TopologyLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TopologyLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TopologyLeaseResponse, ___E> for TopologyLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TopologyLeaseResponse, ___E> for TopologyLeaseResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TopologyLeaseResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TopologyLeaseResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TopologyLeaseResponse>, ___E> for &'a TopologyLeaseResponse
impl<'a, ___E> EncodeOption<Box<'static, TopologyLeaseResponse>, ___E> for &'a TopologyLeaseResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TopologyLeaseResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TopologyLeaseResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TopologyLeaseResponse>, ___E> for TopologyLeaseResponse
impl<___E> EncodeOption<Box<'static, TopologyLeaseResponse>, ___E> for TopologyLeaseResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TopologyLeaseResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TopologyLeaseResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<TopologyLeaseResponse> for TopologyLeaseResponse
impl FromWire<TopologyLeaseResponse> for TopologyLeaseResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TopologyLeaseResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<TopologyLeaseResponse, Self>
Sourcefn from_wire(wire: TopologyLeaseResponse) -> Self
fn from_wire(wire: TopologyLeaseResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<TopologyLeaseResponse> for TopologyLeaseResponse
impl FromWireRef<TopologyLeaseResponse> for TopologyLeaseResponse
Sourcefn from_wire_ref(wire: &TopologyLeaseResponse) -> Self
fn from_wire_ref(wire: &TopologyLeaseResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for TopologyLeaseResponse
impl Hash for TopologyLeaseResponse
Sourceimpl Ord for TopologyLeaseResponse
impl Ord for TopologyLeaseResponse
Sourcefn cmp(&self, other: &TopologyLeaseResponse) -> Ordering
fn cmp(&self, other: &TopologyLeaseResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TopologyLeaseResponse
impl PartialEq for TopologyLeaseResponse
Sourceimpl PartialOrd for TopologyLeaseResponse
impl PartialOrd for TopologyLeaseResponse
impl Copy for TopologyLeaseResponse
impl Eq for TopologyLeaseResponse
impl StructuralPartialEq for TopologyLeaseResponse