LeaseControlServerHandler

Trait LeaseControlServerHandler 

pub trait LeaseControlServerHandler<___T: Transport = Channel> {
    // Required method
    fn watch_status(
        &mut self,
        request: Request<WatchStatus, ___T>,
        responder: Responder<WatchStatus, ___T>,
    ) -> impl Future<Output = ()> + Send;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> + Send { ... }
}
A server handler for the LeaseControl protocol.

See LeaseControl for more details.

Required Methods

fn watch_status( &mut self, request: Request<WatchStatus, ___T>, responder: Responder<WatchStatus, ___T>, ) -> impl Future<Output = ()> + Send

Get the current status of the lease. If last_status is UNKNOWN, the call will return immediately with the current status. Otherwise, the call will block until the current status differs from last_status.

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors