#[repr(C)]pub struct ElementRunnerSetLevelRequest {
pub level: u8,
}Expand description
The wire type corresponding to ElementRunnerSetLevelRequest.
Fields
level: u8Trait Implementations
Sourceimpl Clone for ElementRunnerSetLevelRequest
impl Clone for ElementRunnerSetLevelRequest
Sourcefn clone(&self) -> ElementRunnerSetLevelRequest
fn clone(&self) -> ElementRunnerSetLevelRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ElementRunnerSetLevelRequest
impl Constrained for ElementRunnerSetLevelRequest
Sourceimpl Debug for ElementRunnerSetLevelRequest
impl Debug for ElementRunnerSetLevelRequest
Sourceimpl<___D> Decode<___D> for ElementRunnerSetLevelRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ElementRunnerSetLevelRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ElementRunnerSetLevelRequest, ___E> for &'a ElementRunnerSetLevelRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ElementRunnerSetLevelRequest, ___E> for &'a ElementRunnerSetLevelRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ElementRunnerSetLevelRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ElementRunnerSetLevelRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ElementRunnerSetLevelRequest, ___E> for ElementRunnerSetLevelRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ElementRunnerSetLevelRequest, ___E> for ElementRunnerSetLevelRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ElementRunnerSetLevelRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ElementRunnerSetLevelRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ElementRunnerSetLevelRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ElementRunnerSetLevelRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ElementRunnerSetLevelRequest, ___E> for ElementRunnerSetLevelRequest<T0>
impl<___E, T0> Encode<ElementRunnerSetLevelRequest, ___E> for ElementRunnerSetLevelRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ElementRunnerSetLevelRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ElementRunnerSetLevelRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ElementRunnerSetLevelRequest> for ElementRunnerSetLevelRequest
impl FromWire<ElementRunnerSetLevelRequest> for ElementRunnerSetLevelRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ElementRunnerSetLevelRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ElementRunnerSetLevelRequest, Self>
Sourcefn from_wire(wire: ElementRunnerSetLevelRequest) -> Self
fn from_wire(wire: ElementRunnerSetLevelRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ElementRunnerSetLevelRequest> for ElementRunnerSetLevelRequest
impl FromWireRef<ElementRunnerSetLevelRequest> for ElementRunnerSetLevelRequest
Sourcefn from_wire_ref(wire: &ElementRunnerSetLevelRequest) -> Self
fn from_wire_ref(wire: &ElementRunnerSetLevelRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ElementRunnerSetLevelRequest
impl IntoNatural for ElementRunnerSetLevelRequest
Sourcetype Natural = ElementRunnerSetLevelRequest
type Natural = ElementRunnerSetLevelRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ElementRunnerSetLevelRequest
impl Wire for ElementRunnerSetLevelRequest
Sourcetype Narrowed<'de> = ElementRunnerSetLevelRequest
type Narrowed<'de> = ElementRunnerSetLevelRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.